@@ -3,6 +3,9 @@ import Vision
 
 
 class TestVNError(TestCase):
+    def test_enum_types(self):
+        self.assertIsEnumType(Vision.VNErrorCode)
+
     def testConstants(self):
         self.assertEqual(Vision.VNErrorOK, 0)
         self.assertEqual(Vision.VNErrorRequestCancelled, 1)
@@ -24,3 +27,4 @@ class TestVNError(TestCase):
         self.assertEqual(Vision.VNErrorDataUnavailable, 17)
         self.assertEqual(Vision.VNErrorTimeStampNotFound, 18)
         self.assertEqual(Vision.VNErrorUnsupportedRequest, 19)
+        self.assertEqual(Vision.VNErrorTimeout, 20)
